Batch

Struct Batch 

pub struct Batch<'a> { /* private fields */ }
Batch manages nftables objects and is used to prepare an nftables payload.

Implementations

Source

impl<'a> Batch<'a>

pub fn new() -> Batch<'a>

Creates an empty Batch instance.

pub fn add(&mut self, obj: NfListObject<'a>)

Adds object with add command to Batch.

pub fn delete(&mut self, obj: NfListObject<'a>)

Adds object with delete command to Batch.

pub fn add_cmd(&mut self, cmd: NfCmd<'a>)

Adds a command to Batch.

pub fn add_obj(&mut self, obj: NfListObject<'a>)

Adds a list object (without a command) directly to Batch. This corresponds to the descriptive output format of nft -j list ruleset.

pub fn add_all<I: IntoIterator<Item = NfObject<'a>>>(&mut self, objs: I)

Adds all given objects to the batch.

pub fn to_nftables(self) -> Nftables<'a>

Wraps Batch in nftables object.