pub struct Range<'a> {
pub range: [Expression<'a>; 2],
}Expand description
Construct a range of values. The first array item denotes the lower boundary, the second one the upper boundary.
Fields
range: [Expression<'a>; 2]The range boundaries.
The first array item denotes the lower boundary, the second one the upper boundary.