pub struct Meter<'a> {
pub name: Cow<'a, str>,
pub key: Expression<'a>,
pub stmt: Box<Statement<'a>>,
}Fields
name: Cow<'a, str>key: Expression<'a>stmt: Box<Statement<'a>>Trait Implementations
Sourceimpl<'de, 'a> Deserialize<'de> for Meter<'a>
impl<'de, 'a> Deserialize<'de> for Meter<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'a> JsonSchema for Meter<'a>
impl<'a> JsonSchema for Meter<'a>
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl<'a> Eq for Meter<'a>
impl<'a> StructuralPartialEq for Meter<'a>