pub struct SynProxy<'a> {
pub family: NfFamily,
pub table: Cow<'a, str>,
pub name: Cow<'a, str>,
pub handle: Option<u32>,
pub mss: Option<u16>,
pub wscale: Option<u8>,
pub flags: Option<HashSet<SynProxyFlag>>,
}Expand description
SynProxy intercepts new TCP connections and handles the initial 3-way handshake using syncookies instead of conntrack to establish the connection.
Named SynProxy requires nftables 0.9.3 or newer.
Fields
family: NfFamilyThe table’s family.
table: Cow<'a, str>The table’s name.
name: Cow<'a, str>The synproxy’s name.
handle: Option<u32>The synproxy’s handle. For input, it is used by the delete command only.
mss: Option<u16>The maximum segment size (must match your backend server).
wscale: Option<u8>The window scale (must match your backend server).
flags: Option<HashSet<SynProxyFlag>>The synproxy’s flags.