pub struct Batch<'a> { /* private fields */ }Expand description
Batch manages nftables objects and is used to prepare an nftables payload.
Implementations
Sourceimpl<'a> Batch<'a>
impl<'a> Batch<'a>
Sourcepub fn add(&mut self, obj: NfListObject<'a>)
pub fn add(&mut self, obj: NfListObject<'a>)
Adds object with add command to Batch.
Sourcepub fn delete(&mut self, obj: NfListObject<'a>)
pub fn delete(&mut self, obj: NfListObject<'a>)
Adds object with delete command to Batch.
Sourcepub fn add_obj(&mut self, obj: NfListObject<'a>)
pub fn add_obj(&mut self, obj: NfListObject<'a>)
Adds a list object (without a command) directly to Batch.
This corresponds to the descriptive output format of nft -j list ruleset.
Sourcepub fn add_all<I: IntoIterator<Item = NfObject<'a>>>(&mut self, objs: I)
pub fn add_all<I: IntoIterator<Item = NfObject<'a>>>(&mut self, objs: I)
Adds all given objects to the batch.
Sourcepub fn to_nftables(self) -> Nftables<'a>
pub fn to_nftables(self) -> Nftables<'a>
Wraps Batch in nftables object.