pub struct CTTimeout<'a> {
pub family: NfFamily,
pub table: Cow<'a, str>,
pub name: Cow<'a, str>,
pub handle: Option<u32>,
pub protocol: Option<CTHProto>,
pub state: Option<Cow<'a, str>>,
pub value: Option<u32>,
pub l3proto: Option<Cow<'a, str>>,
}Expand description
This object represents a named conntrack timeout policy.
You can use a ct timeout object to specify a connection tracking timeout policy for a particular flow.
Fields
family: NfFamilyThe table’s family.
table: Cow<'a, str>The table’s name.
name: Cow<'a, str>The ct timeout object’s name.
handle: Option<u32>The ct timeout object’s handle. In input, it is used by the delete command only.
protocol: Option<CTHProto>The ct timeout object’s layer 4 protocol.
state: Option<Cow<'a, str>>The connection state name, e.g. “established”, “syn_sent”, “close” or “close_wait”, for which the timeout value has to be updated.
value: Option<u32>The updated timeout value for the specified connection state.
l3proto: Option<Cow<'a, str>>The ct timeout object’s layer 3 protocol, e.g. “ip” or “ip6”.